@@ -113,6 +113,9 @@ def autoflpy(input_file='Input_File.json'):
     # Generates an appropriate file name
     excel_file_name = name_generator.generated_file_name
 
+    # Imports custom weather data entered into the input file
+    weather_data = data["weather_data"]
+
     # Runs the xlsx converter
 
     log_to_xlsx.log_reader(log_file_path,
@@ -121,7 +124,8 @@ def autoflpy(input_file='Input_File.json'):
                            excel_file_path,
                            excel_file_name,
                            flight_date,
-                           flight_number)
+                           flight_number,
+                           weather_data)
 
     # Assigns variables - checks if any information is entered into the input
     # file for the directories before creating new directories in the current
@@ -238,7 +242,7 @@ def autoflpy(input_file='Input_File.json'):
         copyfile(base_path + 'Your_logo_file_name_here.png',
                  images_path + 'Your_logo_file_name_here.png')
     # Finds the nearest airfield for METAR information
-    ICAO_airfield = nearest_ICAO_finder.icao_finder(flight_data_file_path,
+    icao_airfield = nearest_ICAO_finder.icao_finder(flight_data_file_path,
                                                     flight_data_file_name)
 
     # Runs the flight log generator
@@ -254,10 +258,11 @@ def autoflpy(input_file='Input_File.json'):
                                      flight_log_file_name_header,
                                      checklist_file_path,
                                      log_code_version,
-                                     ICAO_airfield,
+                                     icao_airfield,
                                      start_time_hours,
                                      end_time_hours,
-                                     metar_file_path)
+                                     metar_file_path,
+                                     weather_data)
 
 
 if __name__ == "__main__":
