@@ -36,6 +36,7 @@ class TestLogToXlsx(unittest.TestCase):
         self.excel_file_name = "test_xlsx"
         self.flight_date = self.data["log_to_xlsx_input"]["date"]
         self.flight_number = self.data["log_to_xlsx_input"]["flight_number"]
+        self.weather_data = self.data["weather_data"]
 
     def test_log_reader(self):
         # Make sure the test workbook is closed.
@@ -45,7 +46,8 @@ class TestLogToXlsx(unittest.TestCase):
                                self.excel_file_path,
                                self.excel_file_name,
                                self.flight_date,
-                               self.flight_number)
+                               self.flight_number,
+                               self.weather_data)
 
         def worksheet_tester(sheet, cell, expected_answer):
             """
